.. _rconf-reference-value:

Configuration Value
========================================================================

.. autoclass:: rconf.Leaf

.. class:: rconf.Value

    .. automodule:: rconf._value

    .. literalinclude:: ../../../src/rconf/_value.py
            :language: python
            :lines: 16-
